@@ -2,7 +2,6 @@
 $drivers["pgsql"] = "PostgreSQL";
 
 if (isset($_GET["pgsql"])) {
-	$possible_drivers = array("PgSQL", "PDO_PgSQL");
 	define("DRIVER", "pgsql");
 	if (extension_loaded("pgsql")) {
 		class Min_DB {
@@ -41,7 +40,7 @@ if (isset($_GET["pgsql"])) {
 			}
 
 			function value($val, $field) {
-				return ($field["type"] == "bytea" ? pg_unescape_bytea($val) : $val);
+				return ($field["type"] == "bytea" && $val !== null ? pg_unescape_bytea($val) : $val);
 			}
 
 			function quoteBinary($string) {
@@ -305,7 +304,7 @@ if (isset($_GET["pgsql"])) {
 
 	function tables_list() {
 		$query = "SELECT table_name, table_type FROM information_schema.tables WHERE table_schema = current_schema()";
-		if (support('materializedview')) {
+		if (support('materializedview')) { // ' - support("materializedview") could be removed by compile.php
 			$query .= "
 UNION ALL
 SELECT matviewname, 'MATERIALIZED VIEW'
@@ -349,9 +348,7 @@ WHERE relkind IN ('r', 'm', 'v', 'f', 'p')
 			'timestamp with time zone' => 'timestamptz',
 		);
 
-		$identity_column = min_version(10) ? 'a.attidentity' : '0';
-
-		foreach (get_rows("SELECT a.attname AS field, format_type(a.atttypid, a.atttypmod) AS full_type, pg_get_expr(d.adbin, d.adrelid) AS default, a.attnotnull::int, col_description(c.oid, a.attnum) AS comment, $identity_column AS identity
+		foreach (get_rows("SELECT a.attname AS field, format_type(a.atttypid, a.atttypmod) AS full_type, pg_get_expr(d.adbin, d.adrelid) AS default, a.attnotnull::int, col_description(c.oid, a.attnum) AS comment" . (min_version(10) ? ", a.attidentity" : "") . "
 FROM pg_class c
 JOIN pg_namespace n ON c.relnamespace = n.oid
 JOIN pg_attribute a ON c.oid = a.attrelid
@@ -374,14 +371,14 @@ ORDER BY a.attnum"
 				$row["type"] = $type;
 				$row["full_type"] = $row["type"] . $length . $addon . $array;
 			}
-			if (in_array($row['identity'], array('a', 'd'))) {
-				$row['default'] = 'GENERATED ' . ($row['identity'] == 'd' ? 'BY DEFAULT' : 'ALWAYS') . ' AS IDENTITY';
+			if (in_array($row['attidentity'], array('a', 'd'))) {
+				$row['default'] = 'GENERATED ' . ($row['attidentity'] == 'd' ? 'BY DEFAULT' : 'ALWAYS') . ' AS IDENTITY';
 			}
 			$row["null"] = !$row["attnotnull"];
-			$row["auto_increment"] = $row['identity'] || preg_match('~^nextval\(~i', $row["default"]);
+			$row["auto_increment"] = $row['attidentity'] || preg_match('~^nextval\(~i', $row["default"]);
 			$row["privileges"] = array("insert" => 1, "select" => 1, "update" => 1);
-			if (preg_match('~(.+)::[^)]+(.*)~', $row["default"], $match)) {
-				$row["default"] = ($match[1] == "NULL" ? null : (($match[1][0] == "'" ? idf_unescape($match[1]) : $match[1]) . $match[2]));
+			if (preg_match('~(.+)::[^,)]+(.*)~', $row["default"], $match)) {
+				$row["default"] = ($match[1] == "NULL" ? null : idf_unescape($match[1]) . $match[2]);
 			}
 			$return[$row["field"]] = $row;
 		}
@@ -396,7 +393,7 @@ ORDER BY a.attnum"
 		$return = array();
 		$table_oid = $connection2->result("SELECT oid FROM pg_class WHERE relnamespace = (SELECT oid FROM pg_namespace WHERE nspname = current_schema()) AND relname = " . q($table));
 		$columns = get_key_vals("SELECT attnum, attname FROM pg_attribute WHERE attrelid = $table_oid AND attnum > 0", $connection2);
-		foreach (get_rows("SELECT relname, indisunique::int, indisprimary::int, indkey, indoption , (indpred IS NOT NULL)::int as indispartial FROM pg_index i, pg_class ci WHERE i.indrelid = $table_oid AND ci.oid = i.indexrelid", $connection2) as $row) {
+		foreach (get_rows("SELECT relname, indisunique::int, indisprimary::int, indkey, indoption, (indpred IS NOT NULL)::int as indispartial FROM pg_index i, pg_class ci WHERE i.indrelid = $table_oid AND ci.oid = i.indexrelid", $connection2) as $row) {
 			$relname = $row["relname"];
 			$return[$relname]["type"] = ($row["indispartial"] ? "INDEX" : ($row["indisprimary"] ? "PRIMARY" : ($row["indisunique"] ? "UNIQUE" : "INDEX")));
 			$return[$relname]["columns"] = array();
@@ -421,12 +418,12 @@ WHERE conrelid = (SELECT pc.oid FROM pg_class AS pc INNER JOIN pg_namespace AS p
 AND contype = 'f'::char
 ORDER BY conkey, conname") as $row) {
 			if (preg_match('~FOREIGN KEY\s*\((.+)\)\s*REFERENCES (.+)\((.+)\)(.*)$~iA', $row['definition'], $match)) {
-				$row['source'] = array_map('trim', explode(',', $match[1]));
+				$row['source'] = array_map('idf_unescape', array_map('trim', explode(',', $match[1])));
 				if (preg_match('~^(("([^"]|"")+"|[^"]+)\.)?"?("([^"]|"")+"|[^"]+)$~', $match[2], $match2)) {
-					$row['ns'] = str_replace('""', '"', preg_replace('~^"(.+)"$~', '\1', $match2[2]));
-					$row['table'] = str_replace('""', '"', preg_replace('~^"(.+)"$~', '\1', $match2[4]));
+					$row['ns'] = idf_unescape($match2[2]);
+					$row['table'] = idf_unescape($match2[4]);
 				}
-				$row['target'] = array_map('trim', explode(',', $match[3]));
+				$row['target'] = array_map('idf_unescape', array_map('trim', explode(',', $match[3])));
 				$row['on_delete'] = (preg_match("~ON DELETE ($on_actions)~", $match[4], $match2) ? $match2[1] : 'NO ACTION');
 				$row['on_update'] = (preg_match("~ON UPDATE ($on_actions)~", $match[4], $match2) ? $match2[1] : 'NO ACTION');
 				$return[$row['conname']] = $row;
@@ -491,7 +488,7 @@ ORDER BY connamespace, conname") as $row) {
 	}
 
 	function auto_increment() {
-		return (min_version(11) ? " PRIMARY KEY" : "");
+		return "";
 	}
 
 	function alter_table($table, $name, $fields, $foreign, $comment, $engine, $collation, $auto_increment, $partitioning) {
@@ -508,11 +505,14 @@ ORDER BY connamespace, conname") as $row) {
 			} else {
 				$val5 = $val[5];
 				unset($val[5]);
-				if (isset($val[6]) && $field[0] == "") { // auto_increment
-					$val[1] = ($val[1] == " bigint" ? " big" : ($val[1] == " smallint" ? " small" : " ")) . "serial";
-				}
 				if ($field[0] == "") {
+					if (isset($val[6])) { // auto_increment
+						$val[1] = ($val[1] == " bigint" ? " big" : ($val[1] == " smallint" ? " small" : " ")) . "serial";
+					}
 					$alter[] = ($table != "" ? "ADD " : "  ") . implode($val);
+					if (isset($val[6])) {
+						$alter[] = ($table != "" ? "ADD" : " ") . " PRIMARY KEY ($val[0])";
+					}
 				} else {
 					if ($column != $val[0]) {
 						$queries[] = "ALTER TABLE " . table($name) . " RENAME $column TO $val[0]";
@@ -608,21 +608,34 @@ ORDER BY connamespace, conname") as $row) {
 		return true;
 	}
 
-	function trigger($name, $table = null) {
+	function trigger($name, $table) {
 		if ($name == "") {
 			return array("Statement" => "EXECUTE PROCEDURE ()");
 		}
-		if ($table === null) {
-			$table = $_GET['trigger'];
+		$columns = array();
+		$where = "WHERE trigger_schema = current_schema() AND event_object_table = " . q($table) . " AND trigger_name = " . q($name);
+		foreach (get_rows("SELECT * FROM information_schema.triggered_update_columns $where") as $row) {
+			$columns[] = $row["event_object_column"];
 		}
-		$rows = get_rows('SELECT t.trigger_name AS "Trigger", t.action_timing AS "Timing", (SELECT STRING_AGG(event_manipulation, \' OR \') FROM information_schema.triggers WHERE event_object_table = t.event_object_table AND trigger_name = t.trigger_name ) AS "Events", t.event_manipulation AS "Event", \'FOR EACH \' || t.action_orientation AS "Type", t.action_statement AS "Statement" FROM information_schema.triggers t WHERE t.event_object_table = ' . q($table) . ' AND t.trigger_name = ' . q($name));
-		return reset($rows);
+		$return = array();
+		foreach (get_rows('SELECT trigger_name AS "Trigger", action_timing AS "Timing", event_manipulation AS "Event", \'FOR EACH \' || action_orientation AS "Type", action_statement AS "Statement" FROM information_schema.triggers ' . "$where ORDER BY event_manipulation DESC") as $row) {
+			if ($columns && $row["Event"] == "UPDATE") {
+				$row["Event"] .= " OF";
+			}
+			$row["Of"] = implode(", ", $columns);
+			if ($return) {
+				$row["Event"] .= " OR $return[Event]";
+			}
+			$return = $row;
+		}
+		return $return;
 	}
 
 	function triggers($table) {
 		$return = array();
-		foreach (get_rows("SELECT * FROM information_schema.triggers WHERE event_object_table = " . q($table)) as $row) {
-			$return[$row["trigger_name"]] = array($row["action_timing"], $row["event_manipulation"]);
+		foreach (get_rows("SELECT * FROM information_schema.triggers WHERE trigger_schema = current_schema() AND event_object_table = " . q($table)) as $row) {
+			$trigger = trigger($row["trigger_name"], $table);
+			$return[$trigger["Trigger"]] = array($trigger["Timing"], $trigger["Event"]);
 		}
 		return $return;
 	}
@@ -630,7 +643,7 @@ ORDER BY connamespace, conname") as $row) {
 	function trigger_options() {
 		return array(
 			"Timing" => array("BEFORE", "AFTER"),
-			"Event" => array("INSERT", "UPDATE", "DELETE"),
+			"Event" => array("INSERT", "UPDATE", "UPDATE OF", "DELETE", "INSERT OR UPDATE", "INSERT OR UPDATE OF", "DELETE OR INSERT", "DELETE OR UPDATE", "DELETE OR UPDATE OF", "DELETE OR INSERT OR UPDATE", "DELETE OR INSERT OR UPDATE OF"),
 			"Type" => array("FOR EACH ROW", "FOR EACH STATEMENT"),
 		);
 	}
@@ -774,7 +787,7 @@ AND typelem = 0"
 					: "SELECT * FROM $sequence_name"
 				));
 				$sequences[] = ($style == "DROP+CREATE" ? "DROP SEQUENCE IF EXISTS $sequence_name;\n" : "")
-					. "CREATE SEQUENCE $sequence_name INCREMENT $sq[increment_by] MINVALUE $sq[min_value] MAXVALUE $sq[max_value] START " . ($auto_increment ? $sq['last_value'] : 1) . " CACHE $sq[cache_value];";
+					. "CREATE SEQUENCE $sequence_name INCREMENT $sq[increment_by] MINVALUE $sq[min_value] MAXVALUE $sq[max_value]" . ($auto_increment && $sq['last_value'] ? " START $sq[last_value]" : "") . " CACHE $sq[cache_value];";
 			}
 		}
 
@@ -831,7 +844,7 @@ AND typelem = 0"
 		$return = "";
 		foreach (triggers($table) as $trg_id => $trg) {
 			$trigger = trigger($trg_id, $status['Name']);
-			$return .= "\nCREATE TRIGGER " . idf_escape($trigger['Trigger']) . " $trigger[Timing] $trigger[Events] ON " . idf_escape($status["nspname"]) . "." . idf_escape($status['Name']) . " $trigger[Type] $trigger[Statement];;\n";
+			$return .= "\nCREATE TRIGGER " . idf_escape($trigger['Trigger']) . " $trigger[Timing] $trigger[Event] ON " . idf_escape($status["nspname"]) . "." . idf_escape($status['Name']) . " $trigger[Type] $trigger[Statement];;\n";
 		}
 		return $return;
 	}
@@ -876,32 +889,39 @@ AND typelem = 0"
 		return $connection->result("SHOW max_connections");
 	}
 
-	$jush = "pgsql";
-	$types = array();
-	$structured_types = array();
-	foreach (array( //! arrays
-		lang('Numbers') => array("smallint" => 5, "integer" => 10, "bigint" => 19, "boolean" => 1, "numeric" => 0, "real" => 7, "double precision" => 16, "money" => 20),
-		lang('Date and time') => array("date" => 13, "time" => 17, "timestamp" => 20, "timestamptz" => 21, "interval" => 0),
-		lang('Strings') => array("character" => 0, "character varying" => 0, "text" => 0, "tsquery" => 0, "tsvector" => 0, "uuid" => 0, "xml" => 0),
-		lang('Binary') => array("bit" => 0, "bit varying" => 0, "bytea" => 0),
-		lang('Network') => array("cidr" => 43, "inet" => 43, "macaddr" => 17, "txid_snapshot" => 0),
-		lang('Geometry') => array("box" => 0, "circle" => 0, "line" => 0, "lseg" => 0, "path" => 0, "point" => 0, "polygon" => 0),
-	) as $key => $val) { //! can be retrieved from pg_type
-		$types += $val;
-		$structured_types[$key] = array_keys($val);
+	function driver_config() {
+		$types = array();
+		$structured_types = array();
+		foreach (array( //! arrays
+			lang('Numbers') => array("smallint" => 5, "integer" => 10, "bigint" => 19, "boolean" => 1, "numeric" => 0, "real" => 7, "double precision" => 16, "money" => 20),
+			lang('Date and time') => array("date" => 13, "time" => 17, "timestamp" => 20, "timestamptz" => 21, "interval" => 0),
+			lang('Strings') => array("character" => 0, "character varying" => 0, "text" => 0, "tsquery" => 0, "tsvector" => 0, "uuid" => 0, "xml" => 0),
+			lang('Binary') => array("bit" => 0, "bit varying" => 0, "bytea" => 0),
+			lang('Network') => array("cidr" => 43, "inet" => 43, "macaddr" => 17, "txid_snapshot" => 0),
+			lang('Geometry') => array("box" => 0, "circle" => 0, "line" => 0, "lseg" => 0, "path" => 0, "point" => 0, "polygon" => 0),
+		) as $key => $val) { //! can be retrieved from pg_type
+			$types += $val;
+			$structured_types[$key] = array_keys($val);
+		}
+		return array(
+			'possible_drivers' => array("PgSQL", "PDO_PgSQL"),
+			'jush' => "pgsql",
+			'types' => $types,
+			'structured_types' => $structured_types,
+			'unsigned' => array(),
+			'operators' => array("=", "<", ">", "<=", ">=", "!=", "~", "!~", "LIKE", "LIKE %%", "ILIKE", "ILIKE %%", "IN", "IS NULL", "NOT LIKE", "NOT IN", "IS NOT NULL"), // no "SQL" to avoid CSRF
+			'functions' => array("char_length", "lower", "round", "to_hex", "to_timestamp", "upper"),
+			'grouping' => array("avg", "count", "count distinct", "max", "min", "sum"),
+			'edit_functions' => array(
+				array(
+					"char" => "md5",
+					"date|time" => "now",
+				), array(
+					number_type() => "+/-",
+					"date|time" => "+ interval/- interval", //! escape
+					"char|text" => "||",
+				)
+			),
+		);
 	}
-	$unsigned = array();
-	$operators = array("=", "<", ">", "<=", ">=", "!=", "~", "!~", "LIKE", "LIKE %%", "ILIKE", "ILIKE %%", "IN", "IS NULL", "NOT LIKE", "NOT IN", "IS NOT NULL"); // no "SQL" to avoid CSRF
-	$functions = array("char_length", "lower", "round", "to_hex", "to_timestamp", "upper");
-	$grouping = array("avg", "count", "count distinct", "max", "min", "sum");
-	$edit_functions = array(
-		array(
-			"char" => "md5",
-			"date|time" => "now",
-		), array(
-			number_type() => "+/-",
-			"date|time" => "+ interval/- interval", //! escape
-			"char|text" => "||",
-		)
-	);
 }
