@@ -480,7 +480,7 @@ class Adminer {
 		echo "</script>\n";
 		echo "</div></fieldset>\n";
 	}
-
+	
 	/** Print command box in select
 	* @return bool whether to print default commands
 	*/
@@ -563,6 +563,7 @@ class Adminer {
 					foreach ($fields as $name => $field) {
 						if ((preg_match('~^[-\d.' . (preg_match('~IN$~', $val["op"]) ? ',' : '') . ']+$~', $val["val"]) || !preg_match('~' . number_type() . '|bit~', $field["type"]))
 							&& (!preg_match("~[\x80-\xFF]~", $val["val"]) || preg_match('~char|text|enum|set~', $field["type"]))
+							&& (!preg_match('~date|timestamp~', $field["type"]) || preg_match('~^\d+-\d+-\d+~', $val["val"]))
 						) {
 							$cols[] = $prefix . $driver->convertSearch(idf_escape($name), $val, $field) . $cond;
 						}
@@ -658,6 +659,16 @@ class Adminer {
 		;
 	}
 
+	/** Print before edit form
+	* @param string
+	* @param array
+	* @param mixed
+	* @param bool
+	* @return null
+	*/
+	function editRowPrint($table, $fields, $row, $update) {
+	}
+
 	/** Functions displayed in edit form
 	* @param array single field from fields()
 	* @return array
@@ -665,19 +676,20 @@ class Adminer {
 	function editFunctions($field) {
 		global $edit_functions;
 		$return = ($field["null"] ? "NULL/" : "");
+		$update = isset($_GET["select"]) || where($_GET);
 		foreach ($edit_functions as $key => $functions) {
-			if (!$key || (!isset($_GET["call"]) && (isset($_GET["select"]) || where($_GET)))) { // relative functions
+			if (!$key || (!isset($_GET["call"]) && $update)) { // relative functions
 				foreach ($functions as $pattern => $val) {
 					if (!$pattern || preg_match("~$pattern~", $field["type"])) {
 						$return .= "/$val";
 					}
 				}
-				if ($key && !preg_match('~set|blob|bytea|raw|file|bool~', $field["type"])) {
-					$return .= "/SQL";
-				}
+			}
+			if ($key && !preg_match('~set|blob|bytea|raw|file|bool~', $field["type"])) {
+				$return .= "/SQL";
 			}
 		}
-		if ($field["auto_increment"] && !isset($_GET["select"]) && !where($_GET)) {
+		if ($field["auto_increment"] && !$update) {
 			$return = lang('Auto Increment');
 		}
 		return explode("/", $return);
@@ -944,6 +956,7 @@ class Adminer {
 				echo "<ul id='logins'>\n$output</ul>\n" . script("mixin(qs('#logins'), {onmouseover: menuOver, onmouseout: menuOut});");
 			}
 		} else {
+			$tables = array();
 			if ($_GET["ns"] !== "" && !$missing && DB != "") {
 				$connection->select_db(DB);
 				$tables = table_status('', true);
@@ -1012,8 +1025,8 @@ bodyLoad('<?php echo (is_object($connection) ? preg_replace('~^(\d\.?\d).*~s', '
 			: "<input name='db' value='" . h(DB) . "' autocapitalize='off'>\n"
 		);
 		echo "<input type='submit' value='" . lang('Use') . "'" . ($databases ? " class='hidden'" : "") . ">\n";
-		if ($missing != "db" && DB != "" && $connection->select_db(DB)) {
-			if (support("scheme")) {
+		if (support("scheme")) {
+			if ($missing != "db" && DB != "" && $connection->select_db(DB)) {
 				echo "<br>" . lang('Schema') . ": <select name='ns'>" . optionlist(array("" => "") + $adminer->schemas(), $_GET["ns"]) . "</select>$db_events";
 				if ($_GET["ns"] != "") {
 					set_schema($_GET["ns"]);
@@ -1054,8 +1067,3 @@ bodyLoad('<?php echo (is_object($connection) ? preg_replace('~^(\d\.?\d).*~s', '
 	}
 
 }
-
-$adminer = (function_exists('adminer_object') ? adminer_object() : new Adminer);
-if ($adminer->operators === null) {
-	$adminer->operators = $operators;
-}
