@@ -29,6 +29,9 @@ function version() {
 * @return string
 */
 function idf_unescape($idf) {
+	if (!preg_match('~^[`\'"]~', $idf)) {
+		return $idf;
+	}
 	$last = substr($idf, -1);
 	return str_replace($last . $last, $last, substr($idf, 1, -1));
 }
@@ -1411,15 +1414,16 @@ function on_help($command, $side = 0) {
 * @param bool
 * @return null
 */
-function edit_form($TABLE, $fields, $row, $update) {
+function edit_form($table, $fields, $row, $update) {
 	global $adminer, $jush, $token, $error;
-	$table_name = $adminer->tableName(table_status1($TABLE, true));
+	$table_name = $adminer->tableName(table_status1($table, true));
 	page_header(
 		($update ? lang('Edit') : lang('Insert')),
 		$error,
-		array("select" => array($TABLE, $table_name)),
+		array("select" => array($table, $table_name)),
 		$table_name
 	);
+	$adminer->editRowPrint($table, $fields, $row, $update);
 	if ($row === false) {
 		echo "<p class='error'>" . lang('No rows.') . "\n";
 	}
@@ -1443,7 +1447,7 @@ function edit_form($TABLE, $fields, $row, $update) {
 			$value = ($row !== null
 				? ($row[$name] != "" && $jush == "sql" && preg_match("~enum|set~", $field["type"])
 					? (is_array($row[$name]) ? array_sum($row[$name]) : +$row[$name])
-					: $row[$name]
+					: (is_bool($row[$name]) ? +$row[$name] : $row[$name])
 				)
 				: (!$update && $field["auto_increment"]
 					? ""
@@ -1460,6 +1464,9 @@ function edit_form($TABLE, $fields, $row, $update) {
 					: ($value === false ? null : ($value !== null ? '' : 'NULL'))
 				)
 			);
+			if (!$_POST && !$update && $value == $field["default"] && preg_match('~^[\w.]+\(~', $value)) {
+				$function = "SQL";
+			}
 			if (preg_match("~time~", $field["type"]) && preg_match('~^CURRENT_TIMESTAMP~i', $value)) {
 				$value = "";
 				$function = "now";
