@@ -10,7 +10,7 @@ $translations = array(
 	'Logged as: %s' => 'Logget ind som: %s',
 	'Logout successful.' => 'Log af vellykket.',
 	'Invalid credentials.' => 'Ugyldige log ind oplysninger.',
-	'Master password expired. <a href="https://www.adminer.org/en/extension/" target="_blank">Implement</a> %s method to make it permanent.' => 'Master-kodeordet er udløbet. <a href="https://www.adminer.org/en/extension/" target="_blank">Implementer</a> en metode for %s for at gøre det permanent.',
+	'Master password expired. <a href="https://www.adminer.org/en/extension/"%s>Implement</a> %s method to make it permanent.' => 'Master-kodeordet er udløbet. <a href="https://www.adminer.org/en/extension/"%s>Implementer</a> en metode for %s for at gøre det permanent.',
 	'Language' => 'Sprog',
 	'Invalid CSRF token. Send the form again.' => 'Ugyldigt CSRF-token - Genindsend formen.',
 	'No extension' => 'Ingen udvidelse',
@@ -212,7 +212,7 @@ $translations = array(
 	'last' => 'sidste',
 	'Load more data' => 'Indlæs mere data',
 	'Loading' => 'Indlæser',
-	'whole result' => 'hele resultatet',
+	'Whole result' => 'Hele resultatet',
 	'%d byte(s)' => array('%d byte', '%d bytes'),
 	'Import' => 'Importer',
 	'%d row(s) have been imported.' => array('%d række er importeret.', '%d rækker er importeret.'),
