@@ -11,12 +11,12 @@ $translations = array(
 	'Logged as: %s' => 'Συνδεθήκατε ως %s',
 	'Logout successful.' => 'Αποσυνδεθήκατε με επιτυχία.',
 	'Invalid credentials.' => 'Εσφαλμένα Διαπιστευτήρια.',
-	'Too many unsuccessful logins, try again in %d minute(s).' => array('Επανηλημμένες ανεπιτυχείς προσπάθειες σύνδεσης, δοκιμάστε ξανά σε %s λεπτό.', 'Επανηλημμένες ανεπιτυχείς προσπάθειες σύνδεσης, δοκιμάστε ξανά σε %s λεπτά.'),
-	'Master password expired. <a href="https://www.adminer.org/en/extension/"%s>Implement</a> %s method to make it permanent.' => 'Έλειξε ο Κύριος Κωδικός. <a href="https://www.adminer.org/en/extension/"%s>Ενεργοποιήστε</a> τη μέθοδο %s για να τον κάνετε μόνιμο.',
+	'Too many unsuccessful logins, try again in %d minute(s).' => array('Επανειλημμένες ανεπιτυχείς προσπάθειες σύνδεσης, δοκιμάστε ξανά σε %s λεπτό.', 'Επανειλημμένες ανεπιτυχείς προσπάθειες σύνδεσης, δοκιμάστε ξανά σε %s λεπτά.'),
+	'Master password expired. <a href="https://www.adminer.org/en/extension/"%s>Implement</a> %s method to make it permanent.' => 'Έληξε ο Κύριος Κωδικός. <a href="https://www.adminer.org/en/extension/"%s>Ενεργοποιήστε</a> τη μέθοδο %s για να τον κάνετε μόνιμο.',
 	'Language' => 'Γλώσσα',
 	'Invalid CSRF token. Send the form again.' => 'Άκυρο κουπόνι CSRF. Στείλτε τη φόρμα ξανά.',
 	'If you did not send this request from Adminer then close this page.' => 'Αν δε στείλατε αυτό το αίτημα από το Adminer, τότε κλείστε αυτή τη σελίδα.',
-	'No extension' => 'Χωρίς Επεκτάσεις',
+	'No extension' => 'Καμία Επέκταση',
 	'None of the supported PHP extensions (%s) are available.' => 'Καμία από τις υποστηριζόμενες επεκτάσεις PHP (%s) δεν είναι διαθέσιμη.',
 	'Session support must be enabled.' => 'Πρέπει να είναι ενεργοποιημένη η υποστήριξη συνεδριών.',
 	'Session expired, please login again.' => 'Η συνεδρία έληξε, παρακαλώ συνδεθείτε ξανά.',
@@ -26,7 +26,7 @@ $translations = array(
 	// text direction - 'ltr' or 'rtl'
 	'ltr' => 'ltr',
 	
-	'Privileges' => 'Προνόμια',
+	'Privileges' => 'Δικαιώματα',
 	'Create user' => 'Δημιουργία Χρήστη',
 	'User has been dropped.' => 'Ο Χρήστης διαγράφηκε.',
 	'User has been altered.' => 'Ο Χρήστης τροποποιήθηκε.',
@@ -38,7 +38,7 @@ $translations = array(
 	'Revoke' => 'Ανάκληση',
 	
 	'Process list' => 'Λίστα διεργασιών',
-	'%d process(es) have been killed.' => array('Τερματίστηκαν %d διεργασία.', 'Τερματίστηκαν %d διεργασίες.'),
+	'%d process(es) have been killed.' => array('Τερματίστηκε %d διεργασία.', 'Τερματίστηκαν %d διεργασίες.'),
 	'Kill' => 'Τερματισμός',
 	
 	'Variables' => 'Μεταβλητές',
@@ -46,8 +46,8 @@ $translations = array(
 	
 	'SQL command' => 'Εντολή SQL',
 	'%d query(s) executed OK.' => array('Το ερώτημα %d εκτελέστηκε ΟΚ.', 'Τα ερώτηματα %d εκτελέστηκαν ΟΚ.'),
-	'Query executed OK, %d row(s) affected.' => array('Το ερώτημα εκτελέστηκε ΟΚ, επιρρεάστηκε %d σειρά.', 'Το ερώτημα εκτελέστηκε ΟΚ, επιρρεάστηκαν %d σειρές.'),
-	'No commands to execute.' => 'Δεν υπάρχει εντολή να εκτελεστεί.',
+	'Query executed OK, %d row(s) affected.' => array('Το ερώτημα εκτελέστηκε ΟΚ, επηρεάστηκε %d σειρά.', 'Το ερώτημα εκτελέστηκε ΟΚ, επηρεάστηκαν %d σειρές.'),
+	'No commands to execute.' => 'Δεν υπάρχουν εντολές να εκτελεστούν.',
 	'Error in query' => 'Σφάλμα στο ερώτημα',
 	'Execute' => 'Εκτέλεση',
 	'Stop on error' => 'Διακοπή όταν υπάρχει σφάλμα',
@@ -58,16 +58,16 @@ $translations = array(
 	'Clear' => 'Καθαρισμός',
 	'Edit all' => 'Επεξεργασία όλων',
 	
-	'File upload' => 'Ανέβασμα αρχείου',
+	'File upload' => 'Μεταφόρτωση αρχείου',
 	'From server' => 'Από διακομιστή',
 	'Webserver file %s' => 'Αρχείο %s από διακομιστή web',
 	'Run file' => 'Εκτέλεση αρχείου',
 	'File does not exist.' => 'Το αρχείο δεν υπάρχει.',
-	'File uploads are disabled.' => 'Έχει απενεργοποιηθεί το ανέβασμα αρχείων.',
-	'Unable to upload a file.' => 'Δεν είναι δυνατόν να ανεβεί το αρχείο.',
-	'Maximum allowed file size is %sB.' => 'Το μέγιστο επιτρεπόμενο μέγεθος αρχείο για ανέβασμα είναι %sB.',
+	'File uploads are disabled.' => 'Έχει απενεργοποιηθεί η μεταφόρτωση αρχείων.',
+	'Unable to upload a file.' => 'Αδυναμία μεταφόρτωσης αρχείου.',
+	'Maximum allowed file size is %sB.' => 'Το μέγιστο επιτρεπόμενο μέγεθος αρχείου είναι %sB.',
 	'Too big POST data. Reduce the data or increase the %s configuration directive.' => 'Πολλά δεδομένα POST. Μείωστε τα περιεχόμενα ή αυξήστε την σχετική ρύθμιση %s.',
-	'You can upload a big SQL file via FTP and import it from server.' => 'Μπορείτε να ανεβάσετε ένα μεγάλο αρχείο SQL μέσω FTP και να το εισάγετε από το διακομιστή.',
+	'You can upload a big SQL file via FTP and import it from server.' => 'Μπορείτε να μεταφορτώσετε ένα μεγάλο αρχείο SQL μέσω FTP και να το εισάγετε από το διακομιστή.',
 	'You are offline.' => 'Βρίσκεστε εκτός σύνδεσης.',
 	
 	'Export' => 'Εξαγωγή',
@@ -82,7 +82,7 @@ $translations = array(
 	'database' => 'β. δεδομένων',
 	'Use' => 'χρήση',
 	'Select database' => 'Επιλέξτε Β.Δ.',
-	'Invalid database.' => 'Άκυρη Β.Δ.',
+	'Invalid database.' => 'Λανθασμένη Β.Δ.',
 	'Database has been dropped.' => 'Η Β.Δ. διαγράφηκε.',
 	'Databases have been dropped.' => 'Οι Β.Δ. διαγράφηκαν.',
 	'Database has been created.' => 'Η Β.Δ. δημιουργήθηκε.',
@@ -111,7 +111,7 @@ $translations = array(
 	'Check' => 'Έλεγχος',
 	'Repair' => 'Επιδιόρθωση',
 	'Truncate' => 'Περικοπή',
-	'Tables have been truncated.' => 'Οι πίνακες περικόπτηκαν.',
+	'Tables have been truncated.' => 'Οι πίνακες περικόπηκαν.',
 	'Move to other database' => 'Μεταφορά σε άλλη Β.Δ.',
 	'Move' => 'Μεταφορά',
 	'Tables have been moved.' => 'Οι πίνακες μεταφέρθηκαν.',
@@ -119,11 +119,11 @@ $translations = array(
 	'Tables have been copied.' => 'Οι πίνακες αντιγράφηκαν.',
 	
 	'Routines' => 'Ρουτίνες',
-	'Routine has been called, %d row(s) affected.' => array('Η ρουτίνα εκτελέστηκε, επιρρεάστηκε %d σειρά.', 'Η ρουτίνα εκτελέστηκε, επιρρεάστηκαν %d σειρές.'),
+	'Routine has been called, %d row(s) affected.' => array('Η ρουτίνα εκτελέστηκε, επηρεάστηκε %d σειρά.', 'Η ρουτίνα εκτελέστηκε, επηρεάστηκαν %d σειρές.'),
 	'Call' => 'Εκτέλεση',
 	'Parameter name' => 'Όνομα παραμέτρου',
 	'Create procedure' => 'Δημιουργία διαδικασίας',
-	'Create function' => 'Δημιουργία Λειτουργίας',
+	'Create function' => 'Δημιουργία Συνάρτησης',
 	'Routine has been dropped.' => 'Η ρουτίνα διαγράφηκε.',
 	'Routine has been altered.' => 'Η ρουτίνα τροποποιήθηκε.',
 	'Routine has been created.' => 'Η ρουτίνα δημιουργήθηκε.',
@@ -151,7 +151,7 @@ $translations = array(
 	'Alter table' => 'Τροποποίηση πίνακα',
 	'Create table' => 'Δημιουργία πίνακα',
 	'Table has been dropped.' => 'Ο πίνακας διαγράφηκε.',
-	'Tables have been dropped.' => 'Οι πινακες διαγράφηκαν.',
+	'Tables have been dropped.' => 'Οι πίνακες διαγράφηκαν.',
 	'Tables have been optimized.' => 'Οι πίνακες βελτιστοποιήθηκαν.',
 	'Table has been altered.' => 'Ο πίνακας τροποποιήθηκε.',
 	'Table has been created.' => 'Ο πίνακας δημιουργήθηκε.',
@@ -210,7 +210,7 @@ $translations = array(
 	'Add foreign key' => 'Προσθήκη εξαρτημένου κλειδιού',
 	'ON DELETE' => 'ΚΑΤΑ ΤΗ ΔΙΑΓΡΑΦΗ',
 	'ON UPDATE' => 'ΚΑΤΑ ΤΗΝ ΑΛΛΑΓΗ',
-	'Source and target columns must have the same data type, there must be an index on the target columns and referenced data must exist.' => 'Οι στήλες στη πηγή και το στόχο πρέπει να έχουν τον ίδιο τύπο, πρέπει να υπάρχει δείκτης στη στήλη στόχο και να υπάρχουν εξαρτημένα δεδομένα.',
+	'Source and target columns must have the same data type, there must be an index on the target columns and referenced data must exist.' => 'Οι στήλες στην πηγή και το στόχο πρέπει να έχουν τον ίδιο τύπο, πρέπει να υπάρχει δείκτης στη στήλη στόχο και να υπάρχουν εξαρτημένα δεδομένα.',
 	
 	'Triggers' => 'Εναύσματα',
 	'Add trigger' => 'Προσθήκη εναύσματος',
@@ -262,7 +262,7 @@ $translations = array(
 	'Item%s has been inserted.' => 'Η εγγραφή%s εισήχθη.',
 	'Item has been deleted.' => 'Η εγγραφή διαγράφηκε.',
 	'Item has been updated.' => 'Η εγγραφή ενημερώθηκε.',
-	'%d item(s) have been affected.' => array('Επιρρεάστηκε %d εγγραφή.', 'Επιρρεάστηκαν %d εγγραφές.'),
+	'%d item(s) have been affected.' => array('Επηρεάστηκε %d εγγραφή.', 'Επηρεάστηκαν %d εγγραφές.'),
 	'New item' => 'Νέα εγγραφή',
 	'original' => 'πρωτότυπο',
 	// label for value '' in enum data type
@@ -274,7 +274,7 @@ $translations = array(
 	'Save and continue edit' => 'Αποθήκευση και συνέχεια επεξεργασίας',
 	'Save and insert next' => 'Αποθήκευση και εισαγωγή επόμενου',
 	'Selected' => 'Επιλεγμένα',
-	'Clone' => 'Κλονοποίηση',
+	'Clone' => 'Κλωνοποίηση',
 	'Delete' => 'Διαγραφή',
 	'You have no privileges to update this table.' => 'Δεν έχετε δικαίωμα να τροποποιήσετε αυτό τον πίνακα.',
 	
@@ -283,7 +283,7 @@ $translations = array(
 	'Subject' => 'Θέμα',
 	'Attachments' => 'Συνημμένα',
 	'Send' => 'Αποστολή',
-	'%d e-mail(s) have been sent.' => array('%d e-mail απεστάλλει.', '%d e-mail απεστάλλησαν.'),
+	'%d e-mail(s) have been sent.' => array('%d e-mail απεστάλη.', '%d e-mail απεστάλησαν.'),
 	
 	// data type descriptions
 	'Numbers' => 'Αριθμοί',
