@@ -8,7 +8,6 @@ $translations = array(
 	'Password' => 'Contraseña',
 	'Select database' => 'Seleccionar Base de datos',
 	'Invalid database.' => 'Base de datos incorrecta.',
-	'Create new database' => 'Crear nueva base de datos',
 	'Table has been dropped.' => 'Tabla eliminada.',
 	'Table has been altered.' => 'Tabla modificada.',
 	'Table has been created.' => 'Tabla creada.',
@@ -45,9 +44,9 @@ $translations = array(
 	'Delete' => 'Eliminar',
 	'Database' => 'Base de datos',
 	'Routines' => 'Procedimientos',
-	'Indexes have been altered.' => 'Indices actualizados.',
-	'Indexes' => 'Indices',
-	'Alter indexes' => 'Modificar indices',
+	'Indexes have been altered.' => 'Índices actualizados.',
+	'Indexes' => 'Índices',
+	'Alter indexes' => 'Modificar índices',
 	'Add next' => 'Agregar',
 	'Language' => 'Idioma',
 	'Select' => 'Mostrar',
@@ -78,7 +77,7 @@ $translations = array(
 	'File uploads are disabled.' => 'Importación de archivos deshablilitada.',
 	'Routine has been called, %d row(s) affected.' => array('Consulta ejecutada, %d registro afectado.', 'Consulta ejecutada, %d registros afectados.'),
 	'Call' => 'Llamar',
-	'No extension' => 'No hay extension',
+	'No extension' => 'No hay extensión',
 	'None of the supported PHP extensions (%s) are available.' => 'Ninguna de las extensiones PHP soportadas (%s) está disponible.',
 	'Session support must be enabled.' => 'Deben estar habilitadas las sesiones.',
 	'Session expired, please login again.' => 'Sesión caducada, por favor escriba su clave de nuevo.',
@@ -114,7 +113,7 @@ $translations = array(
 	'Routine has been dropped.' => 'Procedimiento eliminado.',
 	'Routine has been altered.' => 'Procedimiento modificado.',
 	'Routine has been created.' => 'Procedimiento creado.',
-	'Alter function' => 'Modificar Función',
+	'Alter function' => 'Modificar función',
 	'Alter procedure' => 'Modificar procedimiento',
 	'Return type' => 'Tipo de valor de vuelta',
 	'Add trigger' => 'Agregar disparador',
@@ -128,7 +127,7 @@ $translations = array(
 	'%s version: %s through PHP extension %s' => 'Versión %s: %s a través de la extensión de PHP %s',
 	'%d row(s)' => array('%d registro', '%d registros'),
 	'Remove' => 'Eliminar',
-	'Are you sure?' => 'Está seguro?',
+	'Are you sure?' => '¿Está seguro?',
 	'Privileges' => 'Privilegios',
 	'Create user' => 'Crear Usuario',
 	'User has been dropped.' => 'Usuario eliminado.',
@@ -140,7 +139,7 @@ $translations = array(
 	'Grant' => 'Conceder',
 	'Revoke' => 'Impedir',
 	'Too big POST data. Reduce the data or increase the %s configuration directive.' => 'POST data demasiado grande. Reduzca el tamaño o aumente la directiva de configuración %s.',
-	'Logged as: %s' => 'Logeado como: %s',
+	'Logged as: %s' => 'Logueado como: %s',
 	'Move up' => 'Mover arriba',
 	'Move down' => 'Mover abajo',
 	'Functions' => 'Funciones',
@@ -187,12 +186,12 @@ $translations = array(
 	'original' => 'original',
 	'Tables have been dropped.' => 'Tablas eliminadas.',
 	'%d item(s) have been affected.' => array('%d elemento afectado.', '%d elementos afectados.'),
-	'whole result' => 'resultado completo',
+	'Whole result' => 'Resultado completo',
 	'Clone' => 'Clonar',
 	'Maximum number of allowed fields exceeded. Please increase %s.' => 'Excedida la cantidad máxima de campos permitidos. Por favor aumente %s.',
 	'Partition by' => 'Particionar por',
 	'Partitions' => 'Particiones',
-	'Partition name' => 'Nombre de Partición',
+	'Partition name' => 'Nombre de partición',
 	'Values' => 'Valores',
 	'%d row(s) have been imported.' => array('%d registro importado.', '%d registros importados.'),
 	'anywhere' => 'donde sea',
@@ -249,16 +248,16 @@ $translations = array(
 	'System' => 'Motor de base de datos',
 	'Select data' => 'Visualizar contenido',
 	'Show structure' => 'Mostrar estructura',
-	'empty' => 'ningúno',
+	'empty' => 'ninguno',
 	'Network' => 'Red',
 	'Geometry' => 'Geometría',
 	'File exists.' => 'Ese archivo ya existe.',
 	'Attachments' => 'Adjuntos',
-	'%d query(s) executed OK.' => array('%d sentencia sql ejecutada correctamente.', '%d sentencias sql ejecutadas correctamente.'),
+	'%d query(s) executed OK.' => array('%d sentencia SQL ejecutada correctamente.', '%d sentencias SQL ejecutadas correctamente.'),
 	'Show only errors' => 'Mostrar solamente errores',
 	'Refresh' => 'Refrescar',
 	'Invalid schema.' => 'Esquema inválido.',
-	'Please use one of the extensions %s.' => 'Por favor use una de las extensiones %s.',
+	'Please use one of the extensions %s.' => 'Por favor, use una de las extensiones %s.',
 	'now' => 'ahora',
 	'ltr' => 'ltr',
 	'Tables have been copied.' => 'Tablas copiadas.',
