@@ -12,7 +12,7 @@ $translations = array(
 	'Logout successful.' => 'با موفقیت خارج شدید.',
 	'Invalid credentials.' => 'اعتبار سنجی نامعتبر.',
 	'Too many unsuccessful logins, try again in %d minute(s).' => array('ورودهای ناموفق بیش از حد، %d دقیقه دیگر تلاش نمایید.', 'ورودهای ناموفق بیش از حد، %d دقیقه دیگر تلاش نمایید.'),
-	'Master password expired. <a href="https://www.adminer.org/en/extension/" target="_blank">Implement</a> %s method to make it permanent.' => 'رمز اصلی باطل شده است. روش %s را <a href="https://www.adminer.org/en/extension/" target="_blank">پیاده سازی</a> کرده تا آن را دائمی سازید.',
+	'Master password expired. <a href="https://www.adminer.org/en/extension/"%s>Implement</a> %s method to make it permanent.' => 'رمز اصلی باطل شده است. روش %s را <a href="https://www.adminer.org/en/extension/"%s>پیاده سازی</a> کرده تا آن را دائمی سازید.',
 	'Language' => 'زبان',
 	'Invalid CSRF token. Send the form again.' => 'CSRF token نامعتبر است. دوباره سعی کنید.',
 	'No extension' => 'پسوند نامعتبر',
@@ -244,7 +244,7 @@ $translations = array(
 	'last' => 'آخری',
 	'Load more data' => 'بارگزاری اطلاعات بیشتر',
 	'Loading' => 'در حال بارگزاری',
-	'whole result' => 'همه نتایج',
+	'Whole result' => 'همه نتایج',
 	'%d byte(s)' => array('%d بایت', '%d بایت'),
 	
 	'Import' => 'وارد کردن',
