@@ -10,7 +10,7 @@ $translations = array(
 	'Logged as: %s' => 'Logget inn som: %s',
 	'Logout successful.' => 'Utlogging vellykket.',
 	'Invalid credentials.' => 'Ugylding innloggingsinformasjon.',
-	'Master password expired. <a href="https://www.adminer.org/en/extension/" target="_blank">Implement</a> %s method to make it permanent.' => 'Master-passord er utløpt. <a href="https://www.adminer.org/en/extension/" target="_blank">Implementer</a> en metode for %s for å gjøre det permanent.',
+	'Master password expired. <a href="https://www.adminer.org/en/extension/"%s>Implement</a> %s method to make it permanent.' => 'Master-passord er utløpt. <a href="https://www.adminer.org/en/extension/"%s>Implementer</a> en metode for %s for å gjøre det permanent.',
 	'Language' => 'Språk',
 	'Invalid CSRF token. Send the form again.' => 'Ugylding CSRF-token - Send inn skjemaet igjen.',
 	'No extension' => 'Ingen utvidelse',
@@ -212,7 +212,7 @@ $translations = array(
 	'last' => 'siste',
 	'Load more data' => 'Last mer data',
 	'Loading' => 'Laster',
-	'whole result' => 'hele resultatet',
+	'Whole result' => 'Hele resultatet',
 	'%d byte(s)' => array('%d byte', '%d bytes'),
 	'Import' => 'Importer',
 	'%d row(s) have been imported.' => array('%d rad er importert.', '%d rader er importert.'),
