@@ -8,7 +8,6 @@ $translations = array(
 	'Password' => 'க‌ட‌வுச்சொல்',
 	'Select database' => 'த‌க‌வ‌ல்த‌ள‌த்தை தேர்வு செய்',
 	'Invalid database.' => 'த‌க‌வ‌ல்த‌ள‌ம் ச‌ரியானதல்ல‌.',
-	'Create new database' => 'புதிய‌ த‌க‌வ‌ல்த‌ள‌த்தை உருவாக்கு',
 	'Table has been dropped.' => 'அட்ட‌வ‌ணை நீக்க‌ப்ப‌ட்ட‌து.',
 	'Table has been altered.' => 'அட்ட‌வணை மாற்ற‌ப்ப‌ட்ட‌து.',
 	'Table has been created.' => 'அட்ட‌வ‌ணை உருவாக்க‌ப்ப‌ட்ட‌து.',
@@ -31,13 +30,11 @@ $translations = array(
 	'Alter database' => 'த‌க‌வ‌ல்த‌ள‌த்தை மாற்று',
 	'Create database' => 'த‌க‌வ‌ல்த‌ள‌த்தை உருவாக்கு',
 	'SQL command' => 'SQL க‌ட்ட‌ளை',
-	'Dump' => 'Dump',
 	'Logout' => 'வெளியேறு',
 	'database' => 'த‌க‌வ‌ல்த‌ள‌ம்',
 	'Use' => 'உப‌யோகி',
 	'No tables.' => 'அட்ட‌வ‌ணை இல்லை.',
 	'select' => 'தேர்வு செய்',
-	'Create new table' => 'புதிய‌ அட்ட‌வ‌ணையை உருவாக்கு',
 	'Item has been deleted.' => 'உருப்படி நீக்க‌ப்ப‌ட்ட‌து.',
 	'Item has been updated.' => 'உருப்ப‌டி புதுப்பிக்க‌ப்ப‌ட்ட‌து.',
 	'Edit' => 'தொகு',
@@ -138,7 +135,7 @@ $translations = array(
 	'Routine' => 'ரொட்டீன்',
 	'Grant' => 'அனும‌திய‌ளி',
 	'Revoke' => 'இர‌த்துச்செய்',
-	'Too big POST data. Reduce the data or increase the %s configuration directive.' => 'மிக‌ அதிக‌மான‌ POST  த‌க‌வ‌ல். த‌க‌வ‌லை குறைக்க‌வும் அல்ல‌து %s வ‌டிவ‌மைப்பை (configuration directive) மாற்ற‌வும்.',
+	'Too big POST data. Reduce the data or increase the %s configuration directive.' => 'மிக‌ அதிக‌மான‌ POST த‌க‌வ‌ல். த‌க‌வ‌லை குறைக்க‌வும் அல்ல‌து %s வ‌டிவ‌மைப்பை (configuration directive) மாற்ற‌வும்.',
 	'Logged as: %s' => 'ப‌ய‌னாளர்: %s',
 	'Move up' => 'மேலே ந‌க‌ர்த்து',
 	'Move down' => 'கீழே நக‌ர்த்து',
@@ -177,6 +174,7 @@ $translations = array(
 	'Tables have been truncated.' => 'அட்ட‌வ‌ணை குறைக்க‌ப்ப‌ட்ட‌து (truncated).',
 	'Rows' => 'வ‌ரிசைக‌ள்',
 	',' => ',',
+	'0123456789' => '0123456789',
 	'Tables have been moved.' => 'அட்ட‌வ‌ணை ந‌க‌ர்த்த‌ப்ப‌ட்ட‌து.',
 	'Move to other database' => 'ம‌ற்ற‌ த‌க‌வ‌ல் தள‌த்திற்க்கு ந‌க‌ர்த்து',
 	'Move' => 'ந‌க‌ர்த்து',
@@ -185,9 +183,9 @@ $translations = array(
 	'original' => 'அச‌ல்',
 	'Tables have been dropped.' => 'அட்ட‌வ‌ணை நீக்க‌ப்ப‌ட்ட‌து.',
 	'%d item(s) have been affected.' => array('%d உருப்ப‌டி மாற்ற‌ம‌டைந்தது.', '%d உருப்ப‌டிக‌ள் மாற்ற‌ம‌டைந்த‌ன‌.'),
-	'whole result' => 'முழுமையான‌ முடிவு',
+	'Whole result' => 'முழுமையான‌ முடிவு',
 	'Clone' => 'ந‌க‌லி (Clone)',
-	'Maximum number of allowed fields exceeded. Please increase %s and %s.' => 'அனும‌திக்க‌ப்ப‌ட்ட‌ அதிக‌ப‌ட்ச‌ கோப்புக‌ளின் எண்ணிக்கை மீற‌ப்ப‌ட்ட‌து. த‌ய‌வு செய்து %s ம‌ற்றும் %s யை அதிக‌ரிக்க‌வும்.',
+	'Maximum number of allowed fields exceeded. Please increase %s.' => 'அனும‌திக்க‌ப்ப‌ட்ட‌ அதிக‌ப‌ட்ச‌ கோப்புக‌ளின் எண்ணிக்கை மீற‌ப்ப‌ட்ட‌து. த‌ய‌வு செய்து %s ம‌ற்றும் %s யை அதிக‌ரிக்க‌வும்.',
 	'Partition by' => 'பிரித்த‌து',
 	'Partitions' => 'பிரிவுக‌ள்',
 	'Partition name' => 'பிரிவின் பெய‌ர்',
@@ -234,7 +232,6 @@ $translations = array(
 	'Schema has been dropped.' => 'அமைப்புமுறை நீக்க‌ப்ப‌ட்ட‌து.',
 	'Schema has been created.' => 'அமைப்புமுறை உருவாக்க‌ப்ப‌ட்ட‌து.',
 	'Schema has been altered.' => 'அமைப்புமுறை மாற்ற‌ப்ப‌ட்ட‌து.',
-	'Double click on a value to modify it.' => 'ம‌திப்பினை மாற்ற அத‌ன் மீது இருமுறை சொடுக்க‌வும் (Double click).',
 	'Use edit link to modify this value.' => 'இந்த‌ ம‌திப்பினை மாற்ற‌, தொகுப்பு இணைப்பினை உப‌யோகிக்க‌வும்.',
 	'last' => 'க‌டைசி',
 	'Sequence has been dropped.' => 'வ‌ரிசைமுறை நீக்க‌ப்ப‌ட்ட‌து.',
@@ -248,7 +245,6 @@ $translations = array(
 	'System' => 'சிஸ்ட‌ம் (System)',
 	'anywhere' => 'எங்காயினும்',
 	'empty' => 'வெறுமை (empty)',
-	'schema' => 'அமைப்புமுறை',
 	'No extension' => 'விரிவு (extensஇஒன்) இல்லை ',
 	'Databases have been dropped.' => 'த‌க‌வ‌ல் த‌ள‌ங்க‌ள் நீக்க‌ப்ப‌ட்டன‌.',
 	'%s version: %s through PHP extension %s' => '%s ப‌திப்பு: %s through PHP extension %s',
@@ -259,7 +255,6 @@ $translations = array(
 	'now' => 'இப்பொழுது',
 	'%d query(s) executed OK.' => array('%d வின‌வ‌ல் செய‌ல்ப‌டுத்த‌ப்ப‌ட்ட‌து.', '%d வின‌வ‌ல்க‌ள் செய‌ல்ப‌டுத்த‌ப்ப‌ட்ட‌ன‌.'),
 	'Show only errors' => 'பிழைக‌ளை ம‌ட்டும் காண்பிக்க‌வும்',
-	'Last page' => 'க‌டைசி ப‌க்க‌ம்',
 	'Refresh' => 'புதுப்பி (Refresh)',
 	'Invalid schema.' => 'அமைப்புமுறை ச‌ரியான‌த‌ல்ல‌ (Invalid Schema).',
 	'Please use one of the extensions %s.' => 'த‌ய‌வு செய்து ஒரு விரிவினை %s (extension) உப‌யோகிக்க‌வும்.',
@@ -268,6 +263,5 @@ $translations = array(
 	'Copy' => 'நகல்',
 	'Permanent link' => 'நிரந்தர இணைப்பு',
 	'Edit all' => 'அனைத்தையும் தொகு',
-	'Resend POST data?' => 'POST data வை மீண்டும் அனுப்பவா?',
 	'HH:MM:SS' => 'HH:MM:SS',
 );
