@@ -10,8 +10,9 @@ $translations = array(
 	'Logout' => 'Xx',
 	'Logged as: %s' => 'Xx: %s',
 	'Logout successful.' => 'Xx.',
-	'Thanks for using Adminer, consider <a href="%s">donating</a>.' => 'Xx <a href="%s">xx</a>.',
+	'Thanks for using Adminer, consider <a href="https://www.adminer.org/en/donation/">donating</a>.' => 'Xx <a href="https://www.adminer.org/en/donation/">xx</a>.',
 	'Invalid credentials.' => 'Xx.',
+	'There is a space in the input password which might be the cause.' => 'Xx.',
 	'Adminer does not support accessing a database without a password, <a href="https://www.adminer.org/en/password/"%s>more information</a>.' => 'Xx, <a href="https://www.adminer.org/en/password/"%s>xx</a>.',
 	'Database does not support password.' => 'Xx.',
 	'Too many unsuccessful logins, try again in %d minute(s).' => array('Xx %d.', 'Xx %d.'),
@@ -127,6 +128,7 @@ $translations = array(
 	'Tables have been moved.' => 'Xx.',
 	'Copy' => 'Xx',
 	'Tables have been copied.' => 'Xx.',
+	'overwrite' => 'xx',
 	
 	'Routines' => 'Xx',
 	'Routine has been called, %d row(s) affected.' => array('Xx, %d.', 'Xx, %d.'),
