@@ -2,7 +2,7 @@
 $TABLE = $_GET["trigger"];
 $name = $_GET["name"];
 $trigger_options = trigger_options();
-$row = (array) trigger($name) + array("Trigger" => $TABLE . "_bi");
+$row = (array) trigger($name, $TABLE) + array("Trigger" => $TABLE . "_bi");
 
 if ($_POST) {
 	if (!$error && in_array($_POST["Timing"], $trigger_options["Timing"]) && in_array($_POST["Event"], $trigger_options["Event"]) && in_array($_POST["Type"], $trigger_options["Type"])) {
