@@ -3,25 +3,28 @@
 /** Use <select><option> for enum edit instead of <input type="radio">
 * @link https://www.adminer.org/plugins/#use
 * @author Jakub Vrana, https://www.vrana.cz/
-* @license http://www.apache.org/licenses/LICENSE-2.0 Apache License, Version 2.0
-* @license http://www.gnu.org/licenses/gpl-2.0.html GNU General Public License, version 2 (one or other)
+* @license https://www.apache.org/licenses/LICENSE-2.0 Apache License, Version 2.0
+* @license https://www.gnu.org/licenses/gpl-2.0.html GNU General Public License, version 2 (one or other)
 */
 class AdminerEnumOption {
 	
 	function editInput($table, $field, $attrs, $value) {
 		if ($field["type"] == "enum") {
-			$options = array("" => array());
+			$options = array();
 			$selected = $value;
 			if (isset($_GET["select"])) {
-				$options[""][-1] = lang('original');
+				$options[-1] = lang('original');
+				if ($selected === null) {
+					$selected = -1;
+				}
 			}
 			if ($field["null"]) {
-				$options[""][""] = "NULL";
+				$options[""] = "NULL";
 				if ($value === null && !isset($_GET["select"])) {
 					$selected = "";
 				}
 			}
-			$options[""][0] = lang('empty');
+			$options[0] = lang('empty');
 			preg_match_all("~'((?:[^']|'')*)'~", $field["length"], $matches);
 			foreach ($matches[1] as $i => $val) {
 				$val = stripcslashes(str_replace("''", "'", $val));
