@@ -45,7 +45,7 @@ class AdminerFileUpload {
 	}
 
 	function selectVal($val, &$link, $field, $original) {
-		if ($val != "&nbsp;" && preg_match('~(.*)_path$~', $field["field"], $regs)) {
+		if ($val != "" && preg_match('~(.*)_path$~', $field["field"], $regs)) {
 			$link = "$this->displayPath$_GET[select]/$regs[1]-$val";
 		}
 	}
