@@ -3,8 +3,8 @@
 /** Execute writes on master and reads on slave
 * @link https://www.adminer.org/plugins/#use
 * @author Jakub Vrana, https://www.vrana.cz/
-* @license http://www.apache.org/licenses/LICENSE-2.0 Apache License, Version 2.0
-* @license http://www.gnu.org/licenses/gpl-2.0.html GNU General Public License, version 2 (one or other)
+* @license https://www.apache.org/licenses/LICENSE-2.0 Apache License, Version 2.0
+* @license https://www.gnu.org/licenses/gpl-2.0.html GNU General Public License, version 2 (one or other)
 */
 class AdminerMasterSlave {
 	private $masters = array();
@@ -30,7 +30,7 @@ class AdminerMasterSlave {
 		}
 	}
 
-	function messageQuery($query, $time) {
+	function messageQuery($query, $time, $failed = false) {
 		//! doesn't work with sql.inc.php
 		$connection = connection();
 		$result = $connection->query('SHOW MASTER STATUS');
